geolocate package — Geolocate 1.3.0 documentation

# geolocate package

## Subpackages

- geolocate.classes package
  - Submodules
    - geolocate.classes.arguments module
    - geolocate.classes.config module
    - geolocate.classes.geowrapper module
    - geolocate.classes.parser module
    - geolocate.classes.system module
- geolocate.tests package
  - Submodules
  - geolocate.tests.console_mocks module
  - geolocate.tests.test_config module
  - geolocate.tests.test_geolocate module
  - geolocate.tests.test_geowrapper module
  - geolocate.tests.test_parser module
  - geolocate.tests.testing_tools module
  - Module contents

## Submodules

## geolocate.glocate module

This script is the launcher for Geolocate and scans given text to find urls and IP addresses. The output is the same text but every url and IP address is going to have its geolocation appended.

Geolocate is possible thanks to Maxmind GeoIP database and their API.

`geolocate.glocate.` `main`()

`geolocate.glocate.` `print_lines_parsed`(parser)